                            PDP Cross Assembler
                               Version 2.66

--------------------------------------------------------------------------
Definitions
--------------------------------------------------------------------------
    Characters which delimit tokens for equate and macro replacement are
    space, tab, comma, equals sign, left and right parenthesis, at sign,
    pound sign, colon, the expression operators, and the back apostrophe
    (which gets removed):
    " \t,=:,()@#~+-*/&|<>'"

    Characters which delimit other tokens are the same as the equate
    replacement characters.

    Whitespace is spaces and tabs:
    " \t"

    Labels may contain upper and lower case letters, the digits 0-9, the
    underscore, dollar sign, and question mark:
    "_$?0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"

    A label plus a constant, or a label minus a constant may be used
    anywhere a label may be used. Note that a constant plus a label is
    illegal.

    A numeric constant can be made up of a constant, an operator, and another
    constant. All operators are evaluated left to right.
    Operator    Performs
    n+x         Addition
    n-x         Subtraction
    n*x         Multiplication
    n/x         Division
    n&x         Bitwise AND
    n|x         Bitwise OR
    n>x         Unsigned bit shift right n by x bits
    n<x         Unsigned bit shift left n by x bits
    n#x         Bitwise XOR

    A simple numeric constant is a string of digits. The default radix may
    be overridden by affixing a base override. The number may be preceeded
    by +, -, or ~ (binary NOT).
    Token       Radix used for conversion
    nnn         Current radix
    0nnn        Octal
    nnn.        Decimal
    0xnnn       Hexadecimal
    "AB         The two bytes equivalent to A in the high byte and B in the
                low byte
    'A          The two bytes equivalent to A in the low byte and the high
                byte zeroed
    $           Current PC offset from the beginning of the module. Note that
                MODULEBEGIN: is defined as offset zero of this module at link
                time, so MODULEBEGIN+$ is the run time PC.
    ^Bnnn       Binary
    ^Cnnn       The value nnn is complemented. This can be combined with
                another constant. E.g. ^C^B101
    ^Dnnn       Decimal
    ^Onnn       Octal
    ^Rccc       The two bytes equivalent to the RAD-50 encoding of ccc
    ^Xnnn       Hexadecimal

    The registers are defined as R0-R7. SP is R6, PC is R7. Also, F0-F5
    are defined. The registers may also be coded as %0-%7.

--------------------------------------------------------------------------
Command line options
--------------------------------------------------------------------------

    PASM [options] filename[.psm]

    /B
        Inhibit banner of file being assembled

    /D:variable[=value]
        Defines the variable. If value is specified, this behaves the same
        as the line  variable=value  in the source code.

    /E
        Use alternate error format. The default error format is compatible
        with Microsoft C/C++ compiler and other compilers, assemblers,
        and developer's studios, but generates longer error lines.

    /I:path
        Include file path. The path specified preceeds the default path
        specified in the environment variable PIN=

    /L[:{i,m}]
        Create listing file. If you specify /L:I the included files will
        be listed also. If you specify /L:M the macros and equates will
        be added to the listing.

    /M
        Generate this manual.

    /O:file
        Use the specified name for the .POB file.

    /P
        Save the .PSC file. This file is an ASCII representation of the
        object file. Only used for debugging the compiler.


    /P:pagelen
        This specifies the length of the page used in the listing. The
        default page length is 59.

--------------------------------------------------------------------------
Command line options for the linker
--------------------------------------------------------------------------

    PLINK [options] filename[.pob] [filename[.pob] ...]

    /B
        Inhibit banner of file being linked

    /B:file
        Add library module.

    /F
        Allow full 16 bit core image. The default is everything except the
        I/O space (locations 0-157777). Setting /F makes the linker run
        much slower.

    /I:path
        Include file path. The path specified preceeds the default path
        specified in the environment variable POB=

    /L[:file]
        Creates a load map. The default filename is the name of the .PDP
        file with the extension .PMP

    /O
        Allow loader overwrites. Normally the linker will generate an error
        if one location gets loaded more than one time. Note that .LOC,
        .ODD, and .EVEN do not load locations.

    /P:file
        Renames the .PDP file. The default filename is the name of the
        first .POB linked with the extension .PDP

    /U[:file]
        Creates an in use map. The default filename is the name of the .PDP
        file with the extension .PIU. The in use map is a binary bit map
        showing which locations have been loaded by the linker and which have
        not been loaded. The high bit of the first byte is location 0.

    Files specified with the .LIBRARY pseudo-op, and the linker /B: library
switch are searched in the following order.

    1) <file> in the current directory
    2) <file> in the library list (reverse order, ending with PASM.PLB)
    3) <file> in the POB= environment variable
    4) <file>.POB or <file>.PLB in the current directory
    5) <file>.POB or <file>.PLB in the POB= environment variable

--------------------------------------------------------------------------
Command line options for the library builder
--------------------------------------------------------------------------

    PLIB [options] [/B:filename] [{pattern filename} ...]

    /A
        Append the pattern/filenames to the library.

    /B
        Use this library filename. The default is PASM.PLB.

    /C
        Create a new library with files that match these pattern/filenames.

    /N:pattern
        Don't include any files which match the pattern.

--------------------------------------------------------------------------
Simple assemble and link
--------------------------------------------------------------------------

    PAL filename
        This is the same as "PASM filename" "PLINK filename". You must not
        include an extension. If PASM fails, PLINK is inhibited.

--------------------------------------------------------------------------
Extensions used
--------------------------------------------------------------------------

    .PSM
        Source file

    .POB
        Object module. Object modules for the linker may reside in the
        current directory, one specified in /I:path, or in the environment
        variable POB=

    .PSC
        /P output file. ASCII object module.

    .LST
        Listing file

    .PIN
        Include file. Include files for the assembler may reside in the
        current directory, one specified in /I:path, or in the environment
        variable PIN=

    .PIU
        In-use map from the linker

    .PDP
        Core image from the linker

    .PLB
        Library file for the linker. See the linker section above for
        location requirements of .PLB files.

    .PMP
        Load map from the linker


--------------------------------------------------------------------------
Pseudo Ops
--------------------------------------------------------------------------
    .ASCII //
        Generates a sequence of bytes equivalent to the characters given
        between the delimiters. The first non whitespace character is
        the delimiter and the next delimiter must be on the same source
        line as the first delimiter. The \ character is an escape character.
        The character following a \ is interpreted as follows:
        Digraph     Character inserted
        \\          \
        \r \R       Carriage return
        \n \N       New line
        \t \T       Tab
        \b \B       Bell (ASCII 7)
        \<          Less than
        \`          Back apostrophe
        \nnn        Octal value represented by nnn. If there are fewer than
                    three octal digits, only the valid octal digits are
                    interpreted.
        \xnn \Xnn   Hex value represented by nn. If there are fewer than
                    two octal digits, only the valid hex digits are
                    interpreted.
        Other       Illegal

        Also, the sequence <nnn> where nnn is defined in the current base
        will insert the character whose ASCII equivalent is nnn. If you
        need text replacement inside a string, surround the portion with
        back apostrophies.

        Other characters are copied directly.

    .ASCIZ //
        The same as .ASCII, but .ASCIZ appends a single trailing byte of
        ASCII zero.

    .BLKB n
        Reserves n bytes of storage. The linker sets the block to zero.

    .BLKW n
        Reserves n words of storage. The linker sets the block to zero.

    .BYTE n, ...
        Generates a sequence of bytes as specified by the comma delimited
        constants.

    .ELSE
        Used in the middle of an .IF .ENDC block. Reverses the state of the
        conditional assembly.

    .ENDC
        Used to terminate one of the .IF clauses. There must be a matched
        set of .IF and .ENDC.

    .ENDM name
        Used to terminate the .MACRO which began with  .MACRO name

    .ENDR name
        Used to terminate the repeat block which begain with .IRP name


    .ERROR [text]
        Generates an assembly error. This terminates assembly.

    .EVEN
        If the current load address is even, this does nothing. If the
        current load address is odd, adds a single zero byte to ensure the
        load address will be even.

    .FLT2 n,
        Generates a sequence of two word floating point numbers as specified
        by the comma delimited constants. The floating point number is
        converted using the IEEE 10 byte format, and truncated to the correct
        precision. Floating point format is defined by Microsoft C _atold:
        [{+-}][IK0digits][.digits][{dDeE}[[{+-}]digits]

    .FLT4 n,
        Generates a sequence of four word floating point numbers as specified
        by the comma delimited constants. The floating point number is
        converted using the IEEE 10 byte format, and truncated to the correct
        precision. Floating point format is defined by Microsoft C _atold:
        [{+-}][IK0digits][.digits][{dDeE}[[{+-}]digits]

    .IF constant
    .IFT constant
    .IFF constant
        Used to control conditional assembly. If the constant is non-zero,
        the following code is assembled. If the constant is zero, the
        following code is not assembled. .IFT is the same as .IF. .IFF
        assembles code with the opposite test to .IF.

    .IFDEF name
    .IFNDEF name
        Used to control conditional assembly. If the name is either a
        previously defined .MACRO or is an equate, the following code is
        assembled. If the name is neither a .MACRO nor an equate, the
        following code is not assembled. .IFNDEF assembles code with
        the opposite test to .IFDEF

    .IFTF
        Unconditionally assembles code. The rest of the source line is
        ignored. This is typically used to remove conditional assembly
        temporarily.

    .ILG constant
        Allows illegal but codable instructions if constant is non-zero.
        By default, those instructions cause a syntax error.
        E.g. ADDF F6, F0

    .INCLUDE filename
        The file specified by filename is inserted into the source file in
        place of the .INCLUDE line. The filename must exist in the current
        directory, in a directory specified by the PIN environment variable,
        or as specified by /I:path switches from the command line. The
        /I:path switches are searched before the environment variable. The
        default extension is .PIN if none is specified.

    .IRP name, values
        Repeats a block of code. The lines up to but not including the
        .ENDR name  line are repeated where name is replaced by each of the
        values listed. The values are whitespace separated tokens.

    .LABEL name [location]
        Creates a label at the given location. If the location does not start
        with a $- or $+, the value is an absolute core image location. If the
        location is an expression with a leading $- or $+, the location is
        treated as relative to the load time PC. These labels have global
        scope. .LABEL name  without a location is exactly equivalent to
        name::

    .LIBRARY filename[.ext]
        Instructs the linker to add an object to its load. The file specified
        by filename must exist in the current directory, in a directory
        specified by the POB environment variable, or as specified by /I:path
        switches from the linker command line. The /I:path switches are
        searched before the environment variable. The default extension is
        .POB if none is specified.

    .LISTF constant
        Controls whether false conditionals are displayed in the listing
        file. If constant is zero, false conditionals are suppressed.

    .LOC nnn
        Moves the PC to the location specified by the constant nnn. If the PC
        moves beyond the previous highest PC, the core image is zero filled
        by the linker. You may also use  .=nnn   to move the PC.

    .MACRO name, args
        Defines a macro called name. The following lines, up to but not
        including .ENDM are reserved as a macro. The args listed are a
        whitespace terminated list of tokens. When name is found later in
        the program, the macro is invoked and generates the lines specified.
        Each arg listed in the macro definition must have a corresponding
        argument when the macro is invoked. The args listed on the .MACRO
        line and occuring in the macro are replaced with the actual arguments.
        The back apostrophe is removed during token expansion for equates
        and macro arguments.

    .ODD
        If the current load address is odd, this does nothing. If the
        current load address is even, adds a single zero byte to ensure the
        load address will be odd.

    .PAGE
        Forces a page break in the listing file.

    .PRINT [text]
        Displays the text as if an error, without the error indicator

    .PSEUDO .old .new
        Changes the pseudo op from old to new. Following this line, the
        pseudo op .old is no longer recognized. The pseudo op .new assumes
        the function specified by .old.

    .RADIX nnn
        Changes the current radix to the constant specified. The constant
        is always interpreted as a decimal constant unless a radix override
        is present.

    .WARN [text]
        Generates an assembly error, but does not terminate assembly.

    .WORD n,
        Generates a sequence of words as specified by the comma delimited
        constants.

--------------------------------------------------------------------------
Labels
--------------------------------------------------------------------------
    name::
        A global label. This label has a scope of all modules linked.

    name:
        A local label. This label has a scope of the current source file and
        any included files.

    ??:
    ?F[n]
    ?B[n]
        ?? is a generic label. This label may occur any number of times.
        ?F references the next ?? label forward, and ?B references the
        previous ?? label backward. Mostly used to skip a few instructions
        or in small loops which don't need a named label. This label has
        a local scope. ?Fn jumps to the nth label forward. ?F and ?F1 are
        equivalent, as are ?B and ?B1. The number n is decimal.

    name$:
        A temporary label. This label has a scope within the current source
        module, and from the previous local or global label to the next local
        or global label.

    MODULEBEGIN:
        Defined before any other lines are assembled in the current file.
        This label has a local scope. Mostly useful for a program to
        determine where is was loaded.

    MODULEEND:
        Defined after all other lines are assembled in the current file.
        This label has a local scope. Mostly useful for a program to
        determine where is was loaded.

    PDPEND::
        Defined after all modules are linked. This label has a global scope.
        Mostly useful for a program to determine the first available memory
        address for buffers, et. al.

--------------------------------------------------------------------------
Equates
--------------------------------------------------------------------------

    name  =: value
    name  =  value
    name ==: [=]value
    name ==  [=]value
        Replaces the token name with value. Value does not contain leading
        whitespace characters after the = or =:. The equates have a scope of
        the current source file. The back apostrophe is removed during token
        expansion for equates and macro arguments. Equates with the double
        equals sign are arithmetic equates which are evaluated at the time
        of the equate and replaced with ^Onnn where nnn is the octal value.
        When value is preceeded by the equals sign (=), then the arithmetic
        equate is converted to the current radix, instead of ^Onnn. Equates
        can be reassigned unless made permanent (=: and ==:).

--------------------------------------------------------------------------
Listing format
--------------------------------------------------------------------------

    Note that the listing does not reflect the actual PC, nor does it
    reflect any label resolution. In each listing, the PC is relative to
    the beginning of the module after linking. In this example listing,
    the PC has a range from 0 to 6. This code may be loaded anywhere in
    core, however.

    All labels are resolved by the linker, and the assembler indicates
    a label reference with an asterisk following the data which will be
    fixed up by the linker. See the SOB instruction for an example.

C:\EXAMPLE.PSM                     V2.66 1999-09-07 08:09:25      Page 1

Line PC     Data words            Source
   1 000000                       ;---------------------------------
   2 000000                       ; Sample source code
   3 000000                       ;---------------------------------
   4 000000
   5 000000 000005                TopOfProgram: RESET
   6 000002 005000                              CLR     R0
   7 000004 077000*               DelayLoop:    SOB     R0, DelayLoop
   8 000006 012737 123456 160000                MOV     #123456, @#160000

--------------------------------------------------------------------------
Instruction set
--------------------------------------------------------------------------
[This section is a first pass at documenting the instruction set.]

O..O =   8 bit signed PC displacement
B    =   Byte operands
E..E =   EMT trap level
NN   =   Count
CC   =   Count
RR   =   Register number 0-3
DDD  =   Register number 0-7 (110=SP 111=PC) (R in MMM below)
SSS  =   Register number 0-7 (110=SP 111=PC) (R in MMM below)
MMM  =   000 R       Register
         001 (R)     Register deferred
         010 (R)+    Auto increment
         011 @(R)+   Auto increment deferred
         100 -(R)    Auto decrement
         101 @-(R)   Auto decrement deferred
         110 X(R)    Index
         111 @X(R)   Index deferred

     if RRR = 111
         010 #n      Immediate
         011 @#n     Absolute
         110 A       Relative
         111 @A      Relative deferred

ABSD   1 111 000 110 MMM SSS (170600)
ABSF   1 111 000 110 MMM SSS (170600)
ADC    B 000 101 101 MMM DDD (005500)
ADD    0 110 MMM SSS MMM DDD (060000)
ADDD   1 111 010 0RR MMM SSS (172000)
ADDF   1 111 010 0RR MMM SSS (172000)
ASH    0 111 010 RRR MMM SSS (072000)
ASHC   0 111 011 RRR MMM SSS (073000)
ASL    B 000 110 011 MMM DDD (006300)
ASR    B 000 110 010 MMM DDD (006200)
BCC    1 000 011 0OO OOO OOO (103000)
BCS    1 000 011 1OO OOO OOO (103400)
BEQ    0 000 001 1OO OOO OOO (001400)
BGE    0 000 010 0OO OOO OOO (002000)
BGT    0 000 011 0OO OOO OOO (003000)
BHI    1 000 001 0OO OOO OOO (101000)
BHIS   1 000 011 0OO OOO OOO (103000)
BIC    B 100 MMM SSS MMM DDD (040000)
BIS    B 101 MMM SSS MMM DDD (050000)
BIT    B 011 MMM SSS MMM DDD (030000)
BLE    0 000 011 1OO OOO OOO (003400)
BLO    1 000 011 1OO OOO OOO (103400)
BLOS   1 000 001 1OO OOO OOO (101400)
BLT    0 000 010 1OO OOO OOO (002400)
BMI    1 000 000 1OO OOO OOO (100400)
BNE    0 000 001 0OO OOO OOO (001000)
BPL    1 000 000 0OO OOO OOO (100000)
BPT    0 000 000 000 000 011 (000003)
BR     0 000 000 1OO OOO OOO (000400)
BVC    1 000 010 0OO OOO OOO (102000)
BVS    1 000 010 1OO OOO OOO (102400)
C      0 000 000 010 10N NNN (000240)
CALL   0 000 100 111 MMM DDD (004700)
CCC    0 000 000 010 101 111 (000257)
CFCC   1 111 000 000 000 000 (170000)
CLC    0 000 000 010 100 001 (000241)
CLN    0 000 000 010 101 000 (000250)
CLR    B 000 101 000 MMM DDD (005000)
CLRD   1 111 000 100 MMM SSS (170400)
CLRF   1 111 000 100 MMM SSS (170400)
CLV    0 000 000 010 100 010 (000242)
CLZ    0 000 000 010 100 100 (000244)
CMP    B 010 MMM SSS MMM DDD (020000)
CMPD   1 111 011 1RR MMM SSS (173400)
CMPF   1 111 011 1RR MMM SSS (173400)
COM    B 000 101 001 MMM DDD (005100)
CSM    0 000 111 000 MMM DDD (007000)
DEC    B 000 101 011 MMM DDD (005300)
DIV    0 111 001 RRR MMM SSS (071000)
DIVD   1 111 100 1RR MMM SSS (174400)
DIVF   1 111 100 1RR MMM SSS (174400)
EMT    1 000 100 0EE EEE EEE (104000)
FADD   0 111 101 000 000 RRR (075000)
FDIV   0 111 101 000 011 RRR (075030)
FMUL   0 111 101 000 010 RRR (075020)
FSUB   0 111 101 000 001 RRR (075010)
HALT   0 000 000 000 000 000 (000000)
INC    B 000 101 010 MMM DDD (005200)
IOT    0 000 000 000 000 100 (000004)
JMP    0 000 000 001 MMM DDD (000100)
JSR    0 000 100 RRR MMM DDD (004000)
LDCDD  1 111 111 1RR MMM SSS (177400)
LDCDF  1 111 111 1RR MMM SSS (177400)
LDCFD  1 111 111 1RR MMM SSS (177400)
LDCID  1 111 111 0RR MMM SSS (177000)
LDCIF  1 111 111 0RR MMM SSS (177000)
LDCLD  1 111 111 0RR MMM SSS (177000)
LDCLF  1 111 111 0RR MMM SSS (177000)
LDD    1 111 010 1RR MMM SSS (172400)
LDEXP  1 111 110 1RR MMM SSS (176400)
LDF    1 111 010 1RR MMM SSS (172400)
LDFPS  1 111 000 001 MMM SSS (170100)
MARK   0 000 110 100 NNN NNN (006400)
MFPD   1 000 110 101 MMM SSS (106500)
MFPI   0 000 110 101 MMM SSS (006500)
MFPS   1 000 110 111 MMM DDD (106700)
MFPT   0 000 000 000 000 111 (000007)
MODD   1 111 001 1RR MMM SSS (171400)
MODF   1 111 001 1RR MMM SSS (171400)
MOV    B 001 MMM SSS MMM DDD (010000)
MTPD   1 000 110 110 MMM SSS (106600)
MTPI   0 000 110 110 MMM DDD (006600)
MTPS   1 000 110 100 MMM SSS (106400)
MUL    0 111 000 RRR MMM SSS (070000)
MULD   1 111 001 0RR MMM SSS (171000)
MULF   1 111 001 0RR MMM SSS (171000)
NEG    B 000 101 100 MMM DDD (005400)
NEGD   1 111 000 111 MMM SSS (170700)
NEGF   1 111 000 111 MMM SSS (170700)
NOP    0 000 000 010 100 000 (000240)
POP    B 001 010 110 MMM DDD (012600)
PUSH   B 001 MMM SSS 100 110 (010046)
RESET  0 000 000 000 000 101 (000005)
RETURN 0 000 000 010 000 111 (000207)
ROL    B 000 110 001 MMM DDD (006100)
ROR    B 000 110 000 MMM DDD (006000)
RTI    0 000 000 000 000 010 (000002)
RTS    0 000 000 010 000 RRR (000200)
RTT    0 000 000 000 000 110 (000006)
S      0 000 000 010 11N NNN (000260)
SBC    B 000 101 110 MMM DDD (005600)
SCC    0 000 000 010 111 111 (000277)
SEC    0 000 000 010 110 001 (000261)
SEN    0 000 000 010 111 000 (000270)
SETD   1 111 000 000 001 001 (170011)
SETF   1 111 000 000 000 001 (170001)
SETI   1 111 000 000 000 010 (170002)
SETL   1 111 000 000 001 010 (170012)
SEV    0 000 000 010 110 010 (000262)
SEZ    0 000 000 010 110 100 (000264)
SOB    0 111 111 RRR CCC CCC (077000)
SPL    0 000 000 010 011 NNN (000230)
STCDF  1 111 110 0RR MMM SSS (176000)
STCDI  1 111 101 1RR MMM SSS (175400)
STCDL  1 111 101 1RR MMM SSS (175400)
STCFD  1 111 110 0RR MMM SSS (176000)
STCFI  1 111 101 1RR MMM SSS (175400)
STCFL  1 111 101 1RR MMM SSS (175400)
STD    1 111 100 0RR MMM SSS (174000)
STEXP  1 111 101 0RR MMM SSS (175000)
STF    1 111 100 0RR MMM SSS (174000)
STFPS  1 111 000 010 MMM DDD (170200)
STST   1 111 000 011 MMM DDD (170300)
SUB    1 110 MMM SSS MMM DDD (160000)
SUBD   1 111 011 0RR MMM SSS (173000)
SUBF   1 111 011 0RR MMM SSS (173000)
SWAB   0 000 000 011 MMM DDD (000300)
SXT    0 000 110 111 MMM DDD (006700)
TRAP   1 000 100 1EE EEE EEE (104400)
TST    B 000 101 111 MMM DDD (005700)
TSTD   1 111 000 101 MMM SSS (170500)
TSTF   1 111 000 101 MMM SSS (170500)
TSTSET 0 000 111 010 MMM DDD (007200)
WAIT   0 000 000 000 000 001 (000001)
WRTLCK 0 000 111 011 MMM DDD (007300)
XOR    0 111 100 RRR MMM DDD (074000)

The following is clipped from:
http://www.geocities.com/SiliconValley/Heights/2602/pdp11.txt

12. What is the PDP-11 instruction set?
=======================================
     The instruction set of the PDP-11 was heavily influenced by the
     language it was expected to run most often - Fortran. Amongst the
     design constraints were the following: Word length to be a multiple
     of 8 bits; Range extensibility - especially upwards; Interrupt
     responsiveness with multiple interrupt levels for realtime
     computing; Modularity.

     Word length is 16 bits with the leftmost, most significant bit
     (MSB) being bit15. 8 General registers of 16 bits each. or these
     Register 6 is the stack pointer (SP) and Register 7 is the program
     counter (PC). There is also a Processor Status Register/Word (PSW)
     which indicates the 4 condition code bits, the Trace Trap bit,
     processor interrupt priority, and 4 bits for current and previous
     operating modes.  Addressing on the -11 is linear from memory
     address 0 through 777776. Memory management allows access to
     physical memory beyond the 16 bit boundry (177776). All I/O
     devices, registers etc are addressed the same as memory addresses.
     These live in the 4kw of reserved memory space at the top of the
     addressing range. Thus Register 2 (R2) has an address of 777702.
     All word memory addresses are even. In byte operations, and even
     address specified the lower byte and an odd address specifies the
     upper byte. Specifying and odd byte in a word operation will retun
     an odd address trap.  Speaking of which...memory addresses from 0
     to 400 octal are reserved for various exception traps such as
     timeouts, reserved instructions, parity, etc., and device
     interrupts.  Addressing for the Single Operand, Double Operand and
     Jump instructions is achieved via six bits.
      _ _ _ _ _ _
     |x|x|x|_|_|_|
     |Mode |Reg  |

where the modes are as follows: (Reg = Register, Def = Deferred)

Mode 0  Reg     Direct addressing of the register
Mode 1  Reg Def Contents of Reg is the address
Mode 2  AutoIncr Contents of Reg is the address, then Reg incremented.
Mode 3  AutoIncrDef Content of Reg is addr of addr, then Reg Incremented
Mode 4  AutoDecr Reg is decremented then contents is address
Mode 5  AutoDecrDef Reg is decremented then contents is addr of addr
Mode 6  Index   Contents of Reg + Following word is address
Mode 7  IndexDef Contents of Reg + Following word is addr of addr

However, when Reg = 7 (PC):      _ _ _ _ _ _
                                |x|x|x|1|1|1|
                                |Mode |  R7 |

Mode 2  Immediate Operand follows the instruction
Mode 3  Absolute  Address of Operand follows the instruction
Mode 6  Relative  Instr address+4+Next word is Address
Mode 7  RelativeDef Instr address+4+Next word is Address of address

Mainstream instructions are broken into Single operand and Double
operand instructions, which in turn can be word or byte instructions.

Double Operand
--------------
 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _    _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|_|x|x|x|_|_|_|_|_|_|_|_|_|_|_|_|  |1|x|x|x|_|_|_|_|_|_|_|_|_|_|_|_|
| |     |     :     |     :     |  | |     |     :     |     :     |
| | Op  | Source    |  Dest     |  | | Op  | Source    |  Dest     |
         Word Instruction            Byte Instruction (Bit15 Set)
The operands are:
With Bit 15 Clear:               With Bit 15 Set:
-----------------                -----------------
--- 000 All other instructions   ---
MOV 001 Move                     MOVB 001 Move Byte
CMP 010 Compare                  CMPB 010 Compare Byte
BIT 011 Bit Test                 BITB 011 Bit Test Byte
BIC 100 Bit Clear                BICB 100 Bit Clear Byte
BIS 101 Bit Set                  BISB 101 Bit Set  Byte
ADD 110 Add                      SUB  110 Subtract  (Special case)
--- 111 Arithmetic functions
        not in original set

Single Operand
--------------
 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _    _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|0|0|0|0|x|x|x|x|x|x|_|_|_|_|_|_|  |1|0|0|0|x|x|x|x|x|x|_|_|_|_|_|_|
| |     |     :     |     :     |  | |     |     :     |     :     |
| |     | Operand   |  Dest     |  | |     | Operand   |  Dest     |
         Word Instruction            Byte Instruction (Bit15 Set)
The operands are:
With Bit 15 Clear:               With Bit 15 Set:
-----------------                -----------------
000 011 SWAB Swap Bytes
101 000 CLR Clear                101 000 CLRB Clear Byte
101 001 COM Complement           101 001 COMB Complement Byte
010 010 INC Increment            010 010 INCB Increment Byte
101 011 DEC Decrement            101 011 DECB Decrement Byte
101 100 NEG Negate               101 100 NEGB Negate Byte
101 101 ADC AddCarry             101 101 ADCB AddCarry Byte
101 110 SBC SubtractCarry        101 110 SBCB SubtractCarry Byte
101 111 TST Test                 101 111 TSTB Test Byte
110 000 ROR RotateRight          110 000 RORB RotateRight Byte
110 001 ROL RotateLeft           110 001 ROLB RotateLeft Byte
110 010 ASR ArithShftRight       110 010 ASRB ArithShftRight Byte
110 011 ASL ArithShftLeft        110 011 ASLB ArithShftLeft Byte
110 100 MARK Mark                110 100 (Unused)
110 101 MFPI Move From Prev. Ins 110 101 MFPD Move From Prev. Data
110 110 MTPI Move To Prev. Inst. 110 110 MTPD Move To Prev. Data
110 111 SXT Sign Extend          110 111 (Unused)

Branches
--------
 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|x|0|0|0|x|x|x|x|d|d|d|d|d|d|d|d|
| |     |     : |   :     :     |
|O______|_perand|   :  Dest     |

0 000 000 1__   BR      Branch Always
0 000 001 0__   BNE     Branch if not Eq 0
0 000 001 1__   BEQ     Branch if Eq 0
0 000 010 0__   BGE     Branch if GT or Eq 0
0 000 010 1__   BLT     Branch if LT 0
0 000 011 0__   BGT     Branch if GT 0
0 000 011 1__   BLE     Branch if LT or Eq 0
1 000 000 0__   BPL     Branch if Plus
1 000 000 1__   BMI     Branch if Minus
1 000 001 0__   BHI     Branch if Higher
1 000 001 1__   BLOS    Branch if Lower or Same
1 000 010 0__   BVC     Branch if oVerflow Clear
1 000 010 1__   BVS     Branch if oVerflow set
1 000 011 0__   BCC     Branch if Carry Clear (=BHIS Br if Highr or same)
1 000 011 1__   BCS     Branch if Carry Set   (=BLO Br if lower)

Condition Code Operations
-------------------------
 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|0|0|0|0|0|0|0|0|1|0|1|s|N|Z|V|C|
| |     |     |     : | | :     |
|     O p e r a n d   | |MaskBits|

General opcode 000240x. Set/Clear corresponding bits depending on sense
of bit 04. I.e., 000243 will set the V,C bits while 000263 will clear
the V,C bits.

Codes 240 and 260 set/clear no bits and are, thus, used as NOP.

General mnemonics are:
CLx  where x is N Z V or C
SEx
CCC  clear all conditrions codes.
SCC  set all condition codes.


Other, Miscellaneous
--------------------
 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|0|0|0|0|1|0|0|0|0|0|0|0|0|0|0|0|      JSR Jump to Subroutine
| |     | Op  | Reg | Mode| Reg |

 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|0|0|0|0|0|0|0|0|2|0|0|0|0|0|0|0|      RTS Return from Subroutine
| |     |     | Op  |     | Reg |          Use same Reg as the JSR
 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|0|0|0|0|0|0|0|0|0|1|0|0|0|0|0|0|          Jump Always
| |     |     | Op  | Mode| Reg |

 _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
|0|0|0|0|0|0|0|0|0|0|0|0|0|x|x|x|      000 = Halt, 001 = Wait,
| |     |     |     |     | Op  |      010 =RTI Return From Interrupt
                                       100 =BPT Breakpoint Trap
                                       101 =Reset. InitialisesEverything!

Other Arithmatic and floating point instructions were added to the basic
set over the years, but those listed above formed the core PDP-11
instruction set.

